@@ -145,11 +145,11 @@ class NamedMatrix(object):
             rows = range(start, stop, step)
         elif type(rows) is int:
             rows = [rows]
-        elif type(cols) is list:
+        elif type(rows) is list:
             rows = filter(lambda x: not x is None, [i if type(i) is int else self.row_index(i) for i in rows])
         
         if len(cols) == 1 and len(rows) == 1:
-            return self._data[cols[0],rows[0]]
+            return self._data[rows[0],cols[0]]
         
         new_data = [[self._data[i,j] for j in cols] for i in rows]
         new_rownames = [self.rownames[i] for i in rows]
@@ -339,8 +339,7 @@ class NamedMatrix(object):
         if close_file:
             file.close()
     
-    @staticmethod
-    def save_to_hdf5(file, named_matrix):
+    def save_to_hdf5(named_matrix, file):
         """Save named_matrix to an hdf5 file"""
         if not H5PY_SUPPORT:
             raise Exception("You must install the h5py package to use hdf5 file format.")
